@@ -1,6 +1,6 @@
 # coding: utf-8
 """ Primary Maggma module """
-from pkg_resources import get_distribution, DistributionNotFound
+from pkg_resources import DistributionNotFound, get_distribution
 
 try:
     __version__ = get_distribution(__name__).version
