@@ -2,3 +2,5 @@ from maggma.api.query_operator.core import QueryOperator
 from maggma.api.query_operator.dynamic import NumericQuery, StringQueryOperator
 from maggma.api.query_operator.pagination import PaginationQuery
 from maggma.api.query_operator.sparse_fields import SparseFieldsQuery
+from maggma.api.query_operator.sorting import SortQuery
+from maggma.api.query_operator.submission import SubmissionQuery
