@@ -10,7 +10,7 @@ from itertools import chain
 import click
 from monty.serialization import loadfn
 
-from maggma.cli.distributed import master, worker
+from maggma.cli.distributed import find_port, manager, worker
 from maggma.cli.multiprocessing import multi
 from maggma.cli.serial import serial
 from maggma.cli.source_loader import ScriptFinder, load_builder_from_source
@@ -20,7 +20,7 @@ sys.meta_path.append(ScriptFinder())
 
 
 @click.command()
-@click.argument("builders", nargs=-1, type=click.Path(exists=True))
+@click.argument("builders", nargs=-1, type=click.Path(exists=True), required=True)
 @click.option(
     "-v",
     "--verbose",
@@ -44,9 +44,25 @@ sys.meta_path.append(ScriptFinder())
     help="Store in JSON/YAML form to send reporting data to",
     type=click.Path(exists=True),
 )
-@click.option("-u", "--url", "url", default=None, type=str)
+@click.option(
+    "-u", "--url", "url", default=None, type=str, help="URL for the distributed manager"
+)
+@click.option(
+    "-p",
+    "--port",
+    "port",
+    default=None,
+    type=int,
+    help="Port for distributed communication."
+    " mrun will find an open port if None is provided to the manager",
+)
 @click.option("-N", "--num-chunks", "num_chunks", default=0, type=int)
-def run(builders, verbosity, reporting_store, num_workers, url, num_chunks):
+@click.option(
+    "--no_bars", is_flag=True, help="Turns of Progress Bars for headless operations"
+)
+def run(
+    builders, verbosity, reporting_store, num_workers, url, port, num_chunks, no_bars
+):
 
     # Set Logging
     levels = [logging.WARNING, logging.INFO, logging.DEBUG]
@@ -78,16 +94,25 @@ def run(builders, verbosity, reporting_store, num_workers, url, num_chunks):
     if url:
         loop = asyncio.get_event_loop()
         if num_chunks > 0:
-            # Master
-            loop.run_until_complete(master(url, builder_objects, num_chunks))
+            # Manager
+            if port is None:
+                port = find_port()
+                root.critical(f"Using random port for mrun manager: {port}")
+            loop.run_until_complete(
+                manager(
+                    url=url, port=port, builders=builder_objects, num_chunks=num_chunks
+                )
+            )
         else:
             # worker
-            loop.run_until_complete(worker(url, num_workers))
+            loop.run_until_complete(worker(url=url, port=port, num_workers=num_workers))
     else:
         if num_workers == 1:
             for builder in builder_objects:
-                serial(builder)
+                serial(builder, no_bars)
         else:
             loop = asyncio.get_event_loop()
             for builder in builder_objects:
-                loop.run_until_complete(multi(builder, num_workers))
+                loop.run_until_complete(
+                    multi(builder=builder, num_workers=num_workers, no_bars=no_bars)
+                )
